/*
    *
    * This file is a part of CorePad.
    * A document editor for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, write to the Free Software
    * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    * MA 02110-1301, USA.
    *
*/


#ifndef COREPAD_H
#define COREPAD_H

#include <QWidget>
#include <QTextDocument>

#include <cprime/settingsmanage.h>


class CColorScheme;
class CEditor;

namespace Ui {
    class corepad;
}

class corepad : public QWidget {
    Q_OBJECT

public:
    explicit corepad(QWidget *parent = nullptr);
    ~corepad();

    bool initializeNewTab(const QString &filePath);
    void sendFiles(const QStringList &paths);

private slots:
    void on_appTitle_clicked();
    void on_cNew_clicked();
    bool on_cSave_clicked();
    void on_cSaveAs_clicked();
    void on_cCopy_clicked();
    void on_cPaste_clicked();
    void on_cCut_clicked();
    void on_cUndo_clicked();
    void on_cRedo_clicked();
    void on_addDate_clicked();
    void on_search_clicked();
    void on_pinIt_clicked();
    void on_replaceT_clicked();
    void on_replaceAllT_clicked();
    void on_shareIt_clicked();
    void on_nextW_clicked();
    void on_previousW_clicked();

    void textCopyAvailable(bool b);
    void textUndoAvailable(bool b);
    void textRedoAvailable(bool b);

    void on_searchHere_textChanged(const QString &arg1);
    void on_notes_currentChanged(int index);
    void on_notes_tabCloseRequested(int index);

    void updateTab(QString);
    void quitClicked();

    void openFileDialog();

    void on_newTextW_clicked();

protected:
    void closeEvent(QCloseEvent *event);

private:
    Ui::corepad    *ui;
    CColorScheme   *scheme;
    settingsManage *sm = settingsManage::initialize();
    QFont           textViewFont;
    bool            sideView, touch;
    int             sideViewSize, tmpCount;
    QSize           sideViewIconSize, toolButtonIconSize;

    void startSetup();
    void loadSettings();
    void shotcuts();

    bool saveTo(const QString &filePath);
    void findS(QString searchS, bool reverse, QTextDocument::FindFlags flag = nullptr);
    QStringList unsavedFiles();
    bool closeTab(int index);

    CEditor *currentEditor();

};

#endif // COREPAD_H
